.. _functions:

=========
Functions
=========

.. module:: sympy.functions

All functions support the methods documented below, inherited from
:py:class:`sympy.core.function.Function`.

.. autoclass:: sympy.core.function.Function
   :noindex:
   :members:

.. _functions-contents:

Contents
========

.. toctree::
   :maxdepth: 2

   elementary.rst
   combinatorial.rst
   special.rst
